==> hs-fgl-5.4.2.2.tbz: lib/fgl-5.4.2.2/register.sh <==
#!/bin/sh

echo 'name: fgl
version: 5.4.2.2
license: BSD3
copyright:
maintainer: Martin Erwig
stability:
homepage: http://web.engr.oregonstate.edu/~erwig/fgl/haskell
package-url:
description:
category: Data Structures
author: Martin Erwig
exposed: True
exposed-modules: Data.Graph.Inductive.Internal.FiniteMap
                 Data.Graph.Inductive.Internal.Heap
                 Data.Graph.Inductive.Internal.Queue
                 Data.Graph.Inductive.Internal.RootPath
                 Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
                 Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
                 Data.Graph.Inductive.Graphviz Data.Graph.Inductive.Monad
                 Data.Graph.Inductive.NodeMap Data.Graph.Inductive.PatriciaTree
                 Data.Graph.Inductive.Query Data.Graph.Inductive.Tree
                 Data.Graph.Inductive.Monad.IOArray
                 Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
                 Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
                 Data.Graph.Inductive.Query.Dominators
                 Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
                 Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
                 Data.Graph.Inductive.Query.MaxFlow2
                 Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
                 Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules:
import-dirs: /usr/local/lib/fgl-5.4.2.2/ghc-6.10.4
library-dirs: /usr/local/lib/fgl-5.4.2.2/ghc-6.10.4 /usr/local/lib
hs-libraries: HSfgl-5.4.2.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.2.0.0 base-4.1.0.0 containers-0.2.0.1 mtl-1.1.0.2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/fgl-5.4.2.2/html/fgl.haddock
haddock-html: /usr/local/share/doc/fgl-5.4.2.2/html' | /usr/local/bin/ghc-pkg update -

==> hs-fgl-5.4.2.3.tbz: lib/fgl-5.4.2.3/register.sh <==
#!/bin/sh

echo 'name: fgl
version: 5.4.2.3
license: BSD3
copyright:
maintainer: Ivan.Miljenovic@gmail.com, tomberek@gmail.com
stability:
homepage: http://web.engr.oregonstate.edu/~erwig/fgl/haskell
package-url:
description:
category: Data Structures
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
exposed-modules: Data.Graph.Inductive.Internal.FiniteMap
                 Data.Graph.Inductive.Internal.Heap
                 Data.Graph.Inductive.Internal.Queue
                 Data.Graph.Inductive.Internal.RootPath
                 Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
                 Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
                 Data.Graph.Inductive.Graphviz Data.Graph.Inductive.Monad
                 Data.Graph.Inductive.NodeMap Data.Graph.Inductive.PatriciaTree
                 Data.Graph.Inductive.Query Data.Graph.Inductive.Tree
                 Data.Graph.Inductive.Monad.IOArray
                 Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
                 Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
                 Data.Graph.Inductive.Query.Dominators
                 Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
                 Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
                 Data.Graph.Inductive.Query.MaxFlow2
                 Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
                 Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules:
import-dirs: /usr/local/lib/fgl-5.4.2.3/ghc-6.10.4
library-dirs: /usr/local/lib/fgl-5.4.2.3/ghc-6.10.4 /usr/local/lib
hs-libraries: HSfgl-5.4.2.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.2.0.0 base-4.1.0.0 containers-0.2.0.1 mtl-1.1.0.2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/fgl-5.4.2.3/html/fgl.haddock
haddock-html: /usr/local/share/doc/fgl-5.4.2.3/html' | /usr/local/bin/ghc-pkg update -
